import { Connection } from '@solarti/web3.js';

export type Cluster =
  | 'devnet'
  | 'testnet'
  | 'mainnet-beta'
  | 'devnet-mln'
  | 'testnet-mln'
  | 'mainnet-mln'
  | 'localnet'
  | 'custom';

const MAINNET_BETA_DOMAINS = [
  'api.mainnet-mln.miraland.top',
  'api.mainnet-beta.miraland.top',
  'api.mainnet-mln.arcaps.com',
];
const DEVNET_DOMAINS = [
  'api.devnet-mln.miraland.top',
  'api.devnet-mln.arcaps.com',
];
const TESTNET_DOMAINS = ['api.testnet-mln.miraland.top', 'api.testnet-mln.arcaps.com'];
const LOCALNET_DOMAINS = ['localhost', '127.0.0.1'];

export const resolveClusterFromConnection = (
  connection: Connection
): Cluster => {
  return resolveClusterFromEndpoint(connection.rpcEndpoint);
};

export const resolveClusterFromEndpoint = (endpoint: string): Cluster => {
  const domain = new URL(endpoint).hostname;
  if (MAINNET_BETA_DOMAINS.includes(domain)) return 'mainnet-mln';
  if (DEVNET_DOMAINS.includes(domain)) return 'devnet-mln';
  if (TESTNET_DOMAINS.includes(domain)) return 'testnet-mln';
  if (LOCALNET_DOMAINS.includes(domain)) return 'localnet';
  return 'custom';
};
